systemtools
===========

.. automodule:: abjad.tools.systemtools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.systemtools.Configuration.Configuration

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.systemtools.AbjadConfiguration.AbjadConfiguration
      ~abjad.tools.systemtools.BenchmarkScoreMaker.BenchmarkScoreMaker
      ~abjad.tools.systemtools.IOManager.IOManager
      ~abjad.tools.systemtools.ImportManager.ImportManager
      ~abjad.tools.systemtools.LilyPondFormatBundle.LilyPondFormatBundle
      ~abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager
      ~abjad.tools.systemtools.RedirectedStreams.RedirectedStreams
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager
      ~abjad.tools.systemtools.StorageFormatSpecification.StorageFormatSpecification
      ~abjad.tools.systemtools.TestManager.TestManager
      ~abjad.tools.systemtools.Timer.Timer
      ~abjad.tools.systemtools.UpdateManager.UpdateManager
      ~abjad.tools.systemtools.WellformednessManager.WellformednessManager

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.systemtools.requires.requires
      ~abjad.tools.systemtools.run_abjad.run_abjad
